# shopify_apis 

Collection of custom shopify functions

Config file needed at ~/.Shopify-Config.json which will be used by com_digitalruiz_shopify_http_client
```
{
  "shopify_store_name": "YOUR-STORE-NAME",
  "shopify_admin_api_version": "API VERSION",
  "shopify_access_token": "ACCESS TOKEN"
}
```
example use:

```
from com_digitalruiz_shopify_tools import shopify_tools

```
